CHANGELOG
=========

2.0.2 - 2022-04-29

* Fixes LIKE operator search for base64 encoded value

2.0.1 - 2021-03-26

* Fixes packaging bug

2.0.0 - 2021-03-26

* #68 Adds support for Python 3.9 (@2xyo)
* #69 Drops support for Python 2.7, 3.4, 3.5 (@emmanvg)
* #71 Fixes bug with timestamps of a precision greater than microsecond (@freunda)
* #64, #72 Improves performance (@clslgrnc, @dennispo)

1.0.0 - 2020-07-23

* #62 Adds support for Python 3.8 (@2xyo)
* #60 Fixes bug with installing ANTLR dependency (@chisholm)

0.1.0 - 2019-01-10

* Initial prototype with support for STIX 2.0
